==> norsodikin-0.2.7-py3-none-any.whl: nsdev/colorize.py <==
class AnsiColors:
    def __init__(self):
        self.RESET = "\033[0m"

        self.BLACK = "\033[1;38;5;16m"
        self.RED = "\033[1;38;5;196m"
        self.GREEN = "\033[1;38;5;46m"
        self.YELLOW = "\033[1;38;5;226m"
        self.BLUE = "\033[1;38;5;21m"
        self.MAGENTA = "\033[1;38;5;201m"
        self.CYAN = "\033[1;38;5;51m"
        self.WHITE = "\033[1;38;5;231m"
        self.ORANGE = "\033[1;38;5;208m"
        self.PINK = "\033[1;38;5;206m"
        self.GRAY = "\033[1;38;5;244m"
        self.BROWN = "\033[1;38;5;94m"
        self.AQUA = "\033[1;38;5;123m"
        self.PURPLE = "\033[1;38;5;93m"
        self.GOLD = "\033[1;38;5;220m"
        self.SILVER = "\033[1;38;5;250m"
        self.INDIGO = "\033[1;38;5;54m"
        self.TEAL = "\033[1;38;5;30m"
        self.CRIMSON = "\033[1;38;5;160m"
        self.LIME = "\033[1;38;5;154m"
        self.TURQUOISE = "\033[1;38;5;45m"
        self.VIOLET = "\033[1;38;5;128m"
        self.CORAL = "\033[1;38;5;209m"
        self.MAROON = "\033[1;38;5;88m"
        self.NAVY = "\033[1;38;5;17m"
        self.OLIVE = "\033[1;38;5;58m"
        self.BEIGE = "\033[1;38;5;230m"
        self.MINT = "\033[1;38;5;121m"

        self.LIGHT_BLACK = "\033[1;38;5;235m"
        self.LIGHT_RED = "\033[1;38;5;203m"
        self.LIGHT_GREEN = "\033[1;38;5;120m"
        self.LIGHT_YELLOW = "\033[1;38;5;227m"
        self.LIGHT_BLUE = "\033[1;38;5;81m"
        self.LIGHT_MAGENTA = "\033[1;38;5;219m"
        self.LIGHT_CYAN = "\033[1;38;5;87m"
        self.LIGHT_WHITE = "\033[1;38;5;255m"
        self.LIGHT_ORANGE = "\033[1;38;5;214m"
        self.LIGHT_PINK = "\033[1;38;5;218m"
        self.LIGHT_GRAY = "\033[1;38;5;250m"
        self.LIGHT_BROWN = "\033[1;38;5;180m"
        self.LIGHT_AQUA = "\033[1;38;5;159m"
        self.LIGHT_PURPLE = "\033[1;38;5;183m"
        self.LIGHT_GOLD = "\033[1;38;5;228m"
        self.LIGHT_SILVER = "\033[1;38;5;253m"
        self.LIGHT_INDIGO = "\033[1;38;5;99m"
        self.LIGHT_TEAL = "\033[1;38;5;37m"
        self.LIGHT_CRIMSON = "\033[1;38;5;167m"
        self.LIGHT_LIME = "\033[1;38;5;191m"
        self.LIGHT_TURQUOISE = "\033[1;38;5;159m"
        self.LIGHT_VIOLET = "\033[1;38;5;177m"
        self.LIGHT_CORAL = "\033[1;38;5;216m"
        self.LIGHT_MAROON = "\033[1;38;5;131m"
        self.LIGHT_NAVY = "\033[1;38;5;33m"
        self.LIGHT_OLIVE = "\033[1;38;5;100m"
        self.LIGHT_BEIGE = "\033[1;38;5;253m"
        self.LIGHT_MINT = "\033[1;38;5;157m"

    def random_color(self):
        return __import__("random").choice([code for name, code in vars(self).items() if name != "RESET"]), self.RESET

==> norsodikin-0.3.9.dev1-py3-none-any.whl: nsdev/colorize.py <==
class AnsiColors:
    def __init__(self):
        self.RESET = "\033[0m"

        self.BLACK = "\033[1;38;5;16m"
        self.RED = "\033[1;38;5;196m"
        self.GREEN = "\033[1;38;5;46m"
        self.YELLOW = "\033[1;38;5;226m"
        self.BLUE = "\033[1;38;5;21m"
        self.MAGENTA = "\033[1;38;5;201m"
        self.CYAN = "\033[1;38;5;51m"
        self.WHITE = "\033[1;38;5;231m"
        self.ORANGE = "\033[1;38;5;208m"
        self.PINK = "\033[1;38;5;206m"
        self.GRAY = "\033[1;38;5;244m"
        self.BROWN = "\033[1;38;5;94m"
        self.AQUA = "\033[1;38;5;123m"
        self.PURPLE = "\033[1;38;5;93m"
        self.GOLD = "\033[1;38;5;220m"
        self.SILVER = "\033[1;38;5;250m"
        self.INDIGO = "\033[1;38;5;54m"
        self.TEAL = "\033[1;38;5;30m"
        self.CRIMSON = "\033[1;38;5;160m"
        self.LIME = "\033[1;38;5;154m"
        self.TURQUOISE = "\033[1;38;5;45m"
        self.VIOLET = "\033[1;38;5;128m"
        self.CORAL = "\033[1;38;5;209m"
        self.MAROON = "\033[1;38;5;88m"
        self.NAVY = "\033[1;38;5;17m"
        self.OLIVE = "\033[1;38;5;58m"
        self.BEIGE = "\033[1;38;5;230m"
        self.MINT = "\033[1;38;5;121m"

        self.LIGHT_BLACK = "\033[1;38;5;235m"
        self.LIGHT_RED = "\033[1;38;5;203m"
        self.LIGHT_GREEN = "\033[1;38;5;120m"
        self.LIGHT_YELLOW = "\033[1;38;5;227m"
        self.LIGHT_BLUE = "\033[1;38;5;81m"
        self.LIGHT_MAGENTA = "\033[1;38;5;219m"
        self.LIGHT_CYAN = "\033[1;38;5;87m"
        self.LIGHT_WHITE = "\033[1;38;5;255m"
        self.LIGHT_ORANGE = "\033[1;38;5;214m"
        self.LIGHT_PINK = "\033[1;38;5;218m"
        self.LIGHT_GRAY = "\033[1;38;5;250m"
        self.LIGHT_BROWN = "\033[1;38;5;180m"
        self.LIGHT_AQUA = "\033[1;38;5;159m"
        self.LIGHT_PURPLE = "\033[1;38;5;183m"
        self.LIGHT_GOLD = "\033[1;38;5;228m"
        self.LIGHT_SILVER = "\033[1;38;5;253m"
        self.LIGHT_INDIGO = "\033[1;38;5;99m"
        self.LIGHT_TEAL = "\033[1;38;5;37m"
        self.LIGHT_CRIMSON = "\033[1;38;5;167m"
        self.LIGHT_LIME = "\033[1;38;5;191m"
        self.LIGHT_TURQUOISE = "\033[1;38;5;159m"
        self.LIGHT_VIOLET = "\033[1;38;5;177m"
        self.LIGHT_CORAL = "\033[1;38;5;216m"
        self.LIGHT_MAROON = "\033[1;38;5;131m"
        self.LIGHT_NAVY = "\033[1;38;5;33m"
        self.LIGHT_OLIVE = "\033[1;38;5;100m"
        self.LIGHT_BEIGE = "\033[1;38;5;253m"
        self.LIGHT_MINT = "\033[1;38;5;157m"

    def print_all_colors(self):
        colors_dict = vars(self)
        for name, code in colors_dict.items():
            if name != "RESET":
                print(f"{code}{name}{self.RESET}")

    def random_color(self):
        return __import__("random").choice([code for name, code in vars(self).items() if name != "RESET"]), self.RESET
